# -*- coding: utf-8 -*-
# reference.admin

from django.contrib import admin
from django.forms import ModelForm

from . import models


class CommuneAdminForm(ModelForm):
    class Meta:
        model = models.Commune
        fields = '__all__'

    def clean_nom(self):
        return self.cleaned_data["nom"].upper()


class CommuneAdmin(admin.ModelAdmin):
    form = CommuneAdminForm

    class Media:
        js = ('basket/js/list_filter_collapse.js',)

    list_display = [
        'id',
        'nom',
        'postal',
        'departement',
        'agglo',
        'pays',
        'territoire',
        'pnr',
    ]
    list_display_link = ['id']
    list_editable = ['nom', 'postal', 'agglo', 'pays', 'territoire', 'pnr']
    list_filter = ['pnr', 'territoire', 'pays', 'agglo']
    search_fields = ['nom', 'postal']
    readonly_fields = ['departement']
    fieldsets = (
        (None, {'fields': ('nom', 'postal', 'insee', 'departement', 'tag')}),
        (
            'Découpage administratif',
            {
                'fields': ('canton',),
                'classes': ('collapse',),
            },
        ),
        (
            'Info territoriales',
            {'fields': ('territoire', 'agglo', 'pays', 'pnr')},
        ),
    )


admin.site.register(models.Commune, CommuneAdmin)
admin.site.register(models.Canton)
admin.site.register(models.Arrondissement)
admin.site.register(models.Pays)
admin.site.register(models.Territoire)
admin.site.register(models.Agglo)
admin.site.register(models.PNR)
admin.site.register(models.Tag)
