# -*- coding: utf-8 -*-
#
# Copyright (C) 2011, 2012, 2013  Cliss XXI
#
# This file is part of Coccinelle.
#
# Coccinelle is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Coccinelle is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author: Vincent Adolphe

# try to keep it generic as possible

import re

# from django.http import HttpResponse
from django.shortcuts import render

from .. import wash


#
# Envoi d'un courrier electronique
#
def _check_mail(value_qs):
    distinct_emails = []
    for email_set in value_qs:
        # cleanup mailfield: keep only the first one if several are present
        email = email_set[0]
        tmp_name = "{e_set[1]}"
        if len(email_set) > 2 and email_set[2]:
            tmp_name = "{e_set[1]} {e_set[2]}"
        tmp_name = tmp_name.format(e_set=email_set)
        tmp_mail = re.sub(
            '  *',
            ' ',
            email.replace(',', ' ')
            .replace(';', ' ')
            .replace('/', ' ')
            .strip(),
        ).split(' ')
        tmp_mail = tmp_mail[0] if tmp_mail else ''
        tmp_mail = tmp_mail if wash.StringValidator(tmp_mail).isEmail() else ''
        clean_email_set = (tmp_mail, tmp_name)
        if clean_email_set[0] and clean_email_set not in distinct_emails:
            distinct_emails.append(clean_email_set)
    return distinct_emails


def generate_mailto(modeladmin, request, queryset):
    queryset = queryset.order_by('nom')
    mod = queryset.model()
    list_arg = ('courriel', 'nom')
    if hasattr(mod, 'prenom'):
        list_arg = ('courriel', 'nom', 'prenom')
    emails = queryset.exclude(courriel='').values_list(*list_arg)
    distinct_emails = _check_mail(emails)
    context = {
        'destinataires': distinct_emails,
        'nb_dest': len(distinct_emails),
    }
    return render(request, 'courriels.html', context)


generate_mailto.short_description = "Envoyer un courriel..."


def generate_mailto_rel(modeladmin, request, queryset):
    "generate mailto list ordered by 'nom' without dup"
    emails = (
        queryset.exclude(personne__courriel='')
        .order_by('personne__nom')
        .values_list('personne__courriel', 'personne__nom', 'personne__prenom')
    )
    distinct_emails = _check_mail(emails)
    context = {
        'destinataires': distinct_emails,
        'nb_dest': len(distinct_emails),
    }
    return render(request, 'courriels.html', context)


generate_mailto_rel.short_description = (
    "Envoyer un courriel aux personnes physiques..."
)
