# -*- coding: utf-8 -*-
import logging

from django.conf import settings

import djympa

djyLogger = logging.getLogger('djympa')


class CocciSympa(djympa.Djympa):
    """interface entre sympa et coccinelle - c'est ici qu'il y a du code
    specifique a coccinelle pour casser des inclusions multiples et
    permettre d'utiliser cette class dans les models, l'objet est
    initialise avec contacts.models et references.models
    """

    def __init__(self, ListeModel=None, AboListeModel=None, PersonModel=None):
        self.ListeModel = ListeModel
        self.AboListeModel = AboListeModel
        self.PersonModel = PersonModel
        super(CocciSympa, self).__init__(**settings.SYMPA_SOAP)

    def hook_list_dj_lists(self):
        if self.ListeModel is None:
            return []
        return self.ListeModel.objects.all()

    def hook_get_dj_lists_address(self, elm):
        return elm.adresse

    def hook_create_list_dj_lists(self, paddr, dlist, commit=False):
        "hook create or update a django list based on address"
        if self.ListeModel is None:
            return
        try:
            dj_list = self.ListeModel.objects.get(adresse=paddr)
        except (
            self.ListeModel.MultipleObjectsReturned,
            self.ListeModel.DoesNotExist,
        ):
            dj_list = self.ListeModel(
                adresse=paddr, nom=paddr, description=dlist['subject']
            )
        else:
            dj_list.description = dlist['subject']
        dj_list.full_clean()
        if commit:
            dj_list.save()

    def hook_list_dj_addr(self, listname):
        if self.AboListeModel is None:
            return []
        return self.AboListeModel.objects.filter(liste__adresse=listname)

    def hook_get_dj_addr_address(self, elm):
        return elm.personne.courriel

    def hook_unsubscribe_dj_abo(self, elm):
        if elm.status & 0b010:  # statut abonné
            elm.status = 0b1000  # desabonnement par sympa
            djyLogger.debug(
                "mark %s unsubscribed by sympa from list %s"
                % (elm.personne.courriel, elm.liste.adresse)
            )
            elm.save(upd_sympa=False)

    def hook_get_dj_obj_per_mail_addr(self):
        if self.PersonModel is None:
            return {}
        resp = {}
        for elm in self.PersonModel.objects.filter(courriel__isnull=False):
            if elm.courriel in resp:
                resp[elm.courriel].append(elm)
            else:
                resp[elm.courriel] = [elm]
        return resp


# EOF
