# -*- coding: utf-8 -*-
#
# Copyright (C) 2011, 2012, 2013  Cliss XXI
#
# This file is part of Coccinelle.
#
# Coccinelle is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Coccinelle is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author: Vincent Adolphe
#
from functools import reduce
from random import randint

from django import forms
from django.forms import models

from ..references import models as r_mod

# from coccinelle.contacts import models as c_models


class RelationModelForm(models.ModelForm):
    my_select = forms.BooleanField(initial=False, required=False)


class BaseRelationModelFormSet(models.BaseModelFormSet):
    #    def __init__(self, *args, **kwargs):
    #        super(self.__class__,self).__init__(*args, **kwargs)
    #        self.queryset =

    def add_fields(self, form, index):
        super(BaseRelationModelFormSet, self).add_fields(form, index)
        form.fields["my_select"] = forms.BooleanField(initial=False)


class PubSubForm(forms.Form):
    CHOICES = (('desabo', 'désabonnement'), ('abo', 'abonnement'))
    email = forms.EmailField(required=True)


# en attente de fixer le pb d'accent dans le champs gecos
#    nom = forms.CharField(required=False)
#    prenom = forms.CharField(label="Prénom",required=False)


class PubListForm(forms.Form):
    lists = forms.ModelMultipleChoiceField(
        label="Newsletter",
        widget=forms.CheckboxSelectMultiple,
        queryset=r_mod.Liste.objects.filter(public=True, type_l=0),
        required=False,
        help_text="(Diffusion mensuelle)",
    )


class PubThemeListForm(forms.Form):
    lists = forms.ModelMultipleChoiceField(
        label="Listes d'informations thématiques",
        widget=forms.CheckboxSelectMultiple,
        queryset=r_mod.Liste.objects.filter(public=True, type_l=1),
        required=False,
    )


class MathCaptChaForm(forms.Form):
    resultat = forms.IntegerField(label="")
    complexity = 2

    def __init__(self, *args, **kwargs):
        self.math_var = []
        for elm in range(self.complexity):
            self.math_var.append(randint(1, 10))
        self.check_res = kwargs.pop('check_res', None)
        super(MathCaptChaForm, self).__init__(*args, **kwargs)
        if self.math_var:
            self.fields['resultat'].label = "Que font " + " et ".join(
                [str(elm) for elm in self.math_var]
            )

    def get_check_res(self):
        """get this sum when displaying form, then use this result to check
        result in POST using session or whatever other mean."""
        return reduce(lambda x, y: x + y, self.math_var)

    def clean_resultat(self):
        form_res = self.cleaned_data.get('resultat')
        if (
            self.check_res is None
            or form_res is None
            or form_res != self.check_res
        ):
            raise forms.ValidationError("Mauvais calcul...")
        return form_res


# EOF
