# -*- coding: utf-8 -*-
from django.core.management.base import BaseCommand, CommandError

from suds import WebFault

import coccinelle.contacts.models as cm
import coccinelle.references.models as rm
from coccinelle.contacts.cocci_sympa import CocciSympa


class Command(BaseCommand):
    def add_arguments(self, parser):
        parser.description = '''tool to sync data between sympa and cocci'''
        parser.add_argument(
            '--list',
            '-l',
            action='store_true',
            default=False,
            help="list coccinelle lists",
        ),
        parser.add_argument(
            '--sync',
            '-s',
            action='store_true',
            default=False,
            help="sync sympa list into coccinelle lists",
        ),
        parser.add_argument(
            '--review',
            '-r',
            action='store_true',
            default=False,
            help="review address mails for sympa/coccinelle list",
        ),
        parser.add_argument(
            '--unsub',
            '-u',
            action='store_true',
            default=False,
            help="use with '--review', unsubcribe coccinelle address "
            "mails from sympa info (cron)",
        ),
        parser.add_argument(
            '--check_error',
            '-c',
            action='store_true',
            default=False,
            help="check for error reported by sympa",
        ),
        parser.add_argument(
            '--get_from_list',
            '-g',
            dest='source_list',
            action='store_true',
            default=False,
            help="subscribe user based if their mail address is found in sympa",
        ),

    def handle(self, *args, **options):
        sympa = CocciSympa(rm.Liste, cm.AbonnementListe, cm.PersonnePhysique)
        try:
            sympa.login()
        except WebFault as err:
            raise CommandError(err.fault['detail'])
        sympa.get_managed_list()

        if options['list']:
            print("### managed lists by cocci")
            print(("\n".join(sympa.man_lists) + "\n"))
            print("### cocci lists not existing in sympa")
            print(("\n".join(sympa.dj_only_lists) + "\n"))
            print("### sympa lists not existing in cocci")
            print(("\n".join(sympa.sympa_only_lists) + "\n"))
            return

        if options['sync']:
            sympa.sync_django_list_from_sympa(commit=True)
            return

        if options['check_error']:
            # fixme
            return

        if options['source_list']:
            print(
                "# check following address in coccinelle as"
                " they exists both in sympa and coccinelle"
            )
            dj_addrs = sympa.hook_get_dj_obj_per_mail_addr()
            print(("DBG %s" % sympa.man_lists))
            for listname in sympa.man_lists:
                sympa.get_managed_address(listname)
                print(("DBG ### %s" % listname))
                for addr in sympa.dman_lists[listname][
                    'sympa_addr'
                ].intersection(dj_addrs):
                    for model in dj_addrs[addr]:
                        sympa.update_dj_addr_status(
                            listname, addr, model, commit=False
                        )
            #
            return

        if options['review']:
            print(
                "# unsubscribe following address in coccinelle as"
                " they do not exist anymore in sympa"
            )
            for listname in sympa.man_lists:
                sympa.get_managed_address(listname)
                for elm in sympa.dman_lists[listname]['dj_only_addr_obj']:
                    if elm.status & cm.ST_SUB:
                        print(
                            ("%-10s: %s" % (listname, elm.personne.courriel))
                        )
                if options['unsub']:
                    sympa.unsubscribe_dj_abo(listname)
            if not options['unsub']:
                print("# dry run. Relaunch with --unsub for real effect")
            return

        raise CommandError("too few argument")

        self.stdout.write("\n")


# EOF
