from coccinelle.communes.models import PNR, Commune, Pays
from coccinelle.contacts.models import (
    AbonnementListe,
    PersonnePhysique,
    Relation,
    Structure,
)
from coccinelle.references.models import Fonction, Liste


def test_str_personnephysique():
    pers = PersonnePhysique(
        nom="Bombeurre",
        prenom="Jean",
        id=42,
    )
    assert str(pers) == "Jean Bombeurre"
    pers.homonymie = "42"
    assert str(pers) == "Jean Bombeurre (42)"
    assert (
        pers.get_absolute_url()
        == '/admin/contacts/personnephysique/42/change/'
    )


def test_clean_personnephysique():
    pers = PersonnePhysique(nom="Bombeurre")
    pers.clean()
    assert pers.nom == "BOMBEURRE"


def test_str_structure():
    struct = Structure(
        nom="FordEscort",
        id=43,
    )
    assert str(struct) == "FordEscort"
    assert struct.pays() is None
    assert struct.get_pnr() == ""
    com = Commune(nom="terre")
    struct.commune = com
    assert str(struct) == "FordEscort (terre)"
    pays = Pays(nom="Yolo")
    com.pays = pays
    assert struct.pays() == pays
    pnr = PNR(nom="paix i")
    com.pnr = pnr
    assert struct.get_pnr() == pnr
    assert struct.get_absolute_url() == '/admin/contacts/structure/43/change/'


def test_structure_code_p_eff():
    struct = Structure(
        nom="FordEscort",
    )
    assert struct.code_p_eff() == ""
    com = Commune(
        nom="Lievin",
        postal="62800",
    )
    struct.commune = com
    assert struct.code_p_eff() == "62800"
    struct.code_p = '62300'
    assert struct.code_p_eff() == "62300"


def test_str_relation():
    pers = PersonnePhysique(
        nom="Simpson",
        prenom="Homer",
    )
    struct = Structure(nom="Nuclear Plant")
    fonction = Fonction(nom="Security manager")
    rel = Relation(
        personne=pers,
        structure=struct,
        fonction=fonction,
        id=44,
    )
    assert str(rel) == "Homer Simpson, Security manager, Nuclear Plant"
    pers.mob = "0605040302"
    assert rel.mob() == "0605040302"
    pers.tel = "0102030405"
    assert rel.tel() == "0102030405"
    pers.courriel = "homer.simpson@nuke.greenfield.us"
    assert rel.courriel() == "homer.simpson@nuke.greenfield.us"
    struct.tel = "0102030406"
    assert rel.tel_struct() == "0102030406"
    struct.courriel = "nuke@greenfield.us"
    assert rel.courriel_struct() == "nuke@greenfield.us"
    assert rel.get_absolute_url() == '/admin/contacts/relation/44/change/'


def test_str_abonnementliste():
    pers = PersonnePhysique(prenom="yo", nom="lo")
    liste = Liste(nom="list-0", description="TheList")
    alist = AbonnementListe(
        personne=pers,
        liste=liste,
    )
    assert str(alist) == "[TheList] yo lo"
    pers.courriel = "yolo@no.lan"
    assert alist.pcourriel() == "yolo@no.lan"
