# -*- coding: utf-8 -*-
# Create your views here.
from urllib.error import URLError

from django.conf import settings
from django.contrib import messages
from django.contrib.contenttypes.models import ContentType
from django.core.urlresolvers import reverse
from django.forms.models import modelformset_factory
from django.http import Http404
from django.shortcuts import redirect, render

from djympa import WebFault

from . import admin_act_pdf
from . import forms as c_forms
from . import models as c_models
from .cocci_sympa import CocciSympa


def test_view(request, *args, **kwargs):
    test_code = int(kwargs['test_code']) if 'test_code' in kwargs else 200
    if test_code == 500:
        return  # should return 500 if HttpResponse not returned
    if test_code == 501:
        raise Exception("oups")  # should return 500 also
    raise Http404("testé 404")


def pdf_check_label(request):
    "should be called by admin_action, not directly"
    # initialisation de variables
    exclude_dbl = []
    model = None
    # on recupere la queryset depuis la session
    # TODO: a mettre dans une fonction
    if not (
        'admin_qs' in request.session
        and request.session['admin_qs'] is not None
        and request.session['admin_qs']['qsq'] is not None
        and request.session['admin_qs']['ctt'] is not None
        and request.session['admin_qs']['ids'] is not None
    ):
        context = {'error_msg': "Sélection vide..."}
        return render(request, 'pdf_label_check.html', context)
    model = ContentType.objects.get_for_id(
        request.session['admin_qs']['ctt']
    ).model_class()
    queryset = model.objects.filter(id__in=request.session['admin_qs']['ids'])
    queryset = queryset.order_by(request.session['admin_qs']['qsq'])
    # on construit notre ModelFormSet
    # TODO: factoriser form=forms.RelationModelForm
    RelationModelFormSet = modelformset_factory(
        model, form=c_forms.RelationModelForm, fields=('id',), extra=0
    )
    if request.method == 'POST':  # On traite la liste des doublons
        # on recupere la liste en cache
        if (
            'tmp_qs_dbl' in request.session
            and request.session['tmp_qs_dbl'] is not None
        ):
            tmp_qs_dbl = model.objects.filter(
                pk__in=request.session['tmp_qs_dbl']
            )
        relation_formset = RelationModelFormSet(
            request.POST, queryset=tmp_qs_dbl
        )
        if relation_formset.is_valid():
            exclude_dbl = [
                rlf.instance.id
                for rlf in relation_formset
                if not rlf.cleaned_data['my_select']
            ]
            # TODO: factoriser admin_act_pdf.get_rel_text
            return admin_act_pdf.print_label_base(
                None,
                request,
                queryset.exclude(id__in=exclude_dbl),
                admin_act_pdf.get_rel_text,
            )
    else:  # premier affichage -> recherche de doublon
        dbl_id = []
        rel_pre = None
        for rel in queryset:
            if rel_pre is None:
                rel_pre = rel
                continue
            if rel_pre.personne.id == rel.personne.id:
                dbl_id.extend([rel_pre.id, rel.id])
            rel_pre = rel
        if (
            not dbl_id
        ):  # si pas de doublon on déclenche ici l'impression des étiquettes
            return admin_act_pdf.print_label_base(
                None, request, queryset, admin_act_pdf.get_rel_text
            )
        tmp_qs_dbl = queryset.filter(id__in=dbl_id)
        request.session['tmp_qs_dbl'] = dbl_id  # mise en cache
        relation_formset = RelationModelFormSet(queryset=tmp_qs_dbl)
    # tronc commun
    context = {
        'error_msg': False,
        'formset': relation_formset,
        'qs_total': queryset,
        'qs_dbl': tmp_qs_dbl,
        'url_retour': reverse("admin:contacts_relation_changelist"),
    }
    return render(request, 'pdf_label_check.html', context)


def _get_sub(listname, address):
    "get subcription if exists, otherwise return None"
    try:
        return c_models.AbonnementListe.objects.filter(
            liste__adresse=listname, personne__courriel=address
        )[0]
    except IndexError:
        return None


def _get_pp_address(address):
    "get personne that match address if exist otherwise return None"
    try:
        return c_models.PersonnePhysique.objects.filter(courriel=address)[0]
    except IndexError:
        return None


def _update_sub(sub, status):
    "update existing subscription - should not trigger sympa sync"
    sub.status = status
    sub.save()
    return sub


def _create_sub(list_obj, pp_obj, status):
    "create abo - should trigger sympa sync"
    sub = c_models.AbonnementListe(
        liste=list_obj, personne=pp_obj, status=status
    )
    sub.save()
    return sub


def _smart_sub(request, djympa_obj, list_obj, address, is_sub):
    """giving a mail address and a list object, update, create or only
    subscribe to sympa, return abo"""
    abo_status = c_models.ST_USR + (c_models.ST_SUB if is_sub else 0)
    abo = _get_sub(list_obj.adresse, address)
    if abo is not None:
        return _update_sub(abo, abo_status)
    pp = _get_pp_address(address)
    if pp is not None:
        return _create_sub(list_obj, pp, abo_status)
    if is_sub:
        djympa_obj.add(list_obj.adresse, address, quiet=False, force=True)
    else:
        djympa_obj.rem(list_obj.adresse, address, quiet=False, force=True)


def pub_subscribe(request):
    abo = ("se désabonner", "s'abonner")
    if request.method == 'POST':
        sub_form = c_forms.PubSubForm(request.POST, prefix='sub_form')
        list_form = c_forms.PubListForm(request.POST, prefix='list_form')
        theme_form = c_forms.PubThemeListForm(
            request.POST, prefix='theme_form'
        )
        mcaptcha_form = c_forms.MathCaptChaForm(
            request.POST,
            prefix='mcaptcha_form',
            check_res=request.session['mathcaptcha'],
        )
        if (
            sub_form.is_valid()
            and list_form.is_valid()
            and theme_form.is_valid()
            and mcaptcha_form.is_valid()
        ):
            if not (
                list(list_form.cleaned_data['lists'])
                + list(theme_form.cleaned_data['lists'])
            ):
                messages.error(
                    request, "Vous devez choisir au moins une liste"
                )
                return redirect('pub_subscribe')
            try:
                sympa = CocciSympa()
                sympa.login()
            except URLError:
                # set messages
                messages.error(
                    request, "Impossible de télécharger la description WSDL"
                )
                return redirect('pub_subscribe')
            except WebFault as err:
                messages.error(request, err.fault['detail'])
                return redirect('pub_subscribe')
            for dlist in list(list_form.cleaned_data['lists']) + list(
                theme_form.cleaned_data['lists']
            ):
                _smart_sub(
                    request,
                    sympa,
                    dlist,
                    sub_form.cleaned_data['email'],
                    request.POST['action'] == "abo",
                )
                messages.info(
                    request,
                    "%sabonnement de %s à la liste %s"
                    % (
                        "" if request.POST['action'] == "abo" else "dé",
                        sub_form.cleaned_data['email'],
                        dlist.adresse,
                    ),
                )
            return redirect('pub_sub_redir')
        else:  # one of forms is invalid
            pass
    else:  # 1er affichage
        sub_form = c_forms.PubSubForm(prefix='sub_form')
        list_form = c_forms.PubListForm(prefix='list_form')
        theme_form = c_forms.PubThemeListForm(prefix='theme_form')
        mcaptcha_form = c_forms.MathCaptChaForm(prefix='mcaptcha_form')
    # common part
    request.session['mathcaptcha'] = mcaptcha_form.get_check_res()
    context = {
        'self_url': reverse('pub_subscribe'),
        'abo': abo,
        'sub_form': sub_form,
        'list_form': list_form,
        'theme_form': theme_form,
        'mcaptcha_form': mcaptcha_form,
        'footer': settings.SUBSCRIBE_FOOTER,
    }
    return render(request, 'pub_subscribe.html', context)


def pub_sub_redir(request):
    redir_url = getattr(
        settings, 'SUBSCRIBE_REDIRECT_URL', reverse('pub_subscribe')
    )
    redir_url = redir_url or reverse('pub_subscribe')
    context = {
        'timeout': getattr(settings, 'SUBSCRIBE_REDIRECT_TIMEOUT', 0),
        'redir_url': redir_url,
    }
    return render(request, 'pub_sub_redir.html', context)


# EOF
