# -*- coding: utf-8 -*-
# reference
from django.db import models

TYPE_LISTE = (
    (0, "newsletter"),
    (1, "liste thématique"),
)

# Create your models here.


# common field:
class Tag(models.Model):
    class Meta:
        verbose_name = "Étiquette"
        abstract = True

    nom = models.CharField(max_length=20, verbose_name="Étiquette(s)")
    description = models.CharField(
        max_length=100, verbose_name="Description", blank=True
    )

    def __str__(self):
        return "%s" % (self.nom)


class Fonction(models.Model):
    class Meta:
        verbose_name = "Fonction"
        ordering = ('nom',)

    nom = models.CharField(max_length=100, verbose_name="Fonction")

    def __str__(self):
        return "%s" % (self.nom)


# Structure helper:
class Statut(models.Model):
    class Meta:
        verbose_name = "Statut structure"
        verbose_name_plural = "Statuts structures"
        ordering = ('nom',)

    nom = models.CharField(max_length=100, verbose_name="Statut")
    description = models.CharField(
        max_length=200, verbose_name="Description", blank=True
    )

    def __str__(self):
        return "%s" % (self.nom)


class TagStructure(Tag):
    class Meta:
        ordering = ('nom',)
        verbose_name = "Étiquette Structure"
        verbose_name_plural = "Étiquettes Structures"

    pass


# Personne Physique helper:
class StatutPerso(models.Model):
    class Meta:
        verbose_name = "Statut individuel"
        verbose_name_plural = "Statuts individuels"
        ordering = ('nom',)

    nom = models.CharField(max_length=100, verbose_name="Statut Personnel")

    def __str__(self):
        return "%s" % (self.nom)


class CerddCentral(models.Model):
    class Meta:
        verbose_name = "Rôle au sein du CERDD"
        verbose_name_plural = "Rôles au sein du CERDD"
        ordering = ('nom',)

    nom = models.CharField(
        max_length=100, verbose_name="Rôle au sein du Cerdd"
    )
    description = models.CharField(
        max_length=200, verbose_name="Description", blank=True
    )

    def __str__(self):
        return "%s" % (self.nom)


class CerddProgramme(models.Model):
    class Meta:
        verbose_name = "Programme du CERDD"
        verbose_name_plural = "Programmes du CERDD"
        ordering = ('nom',)

    nom = models.CharField(max_length=100, verbose_name="Programme du Cerdd")
    description = models.CharField(
        max_length=200, verbose_name="Description", blank=True
    )

    def __str__(self):
        return "%s" % (self.nom)


class TagPersonnePhysique(Tag):
    class Meta:
        verbose_name = "Étiquette Personne physique"
        verbose_name_plural = "Étiquettes Personnes physiques"
        ordering = ('nom',)

    pass


class Liste(models.Model):
    class Meta:
        verbose_name = "Liste de diffusion"
        ordering = ("description",)

    nom = models.CharField(max_length=100, verbose_name="Nom")
    adresse = models.CharField(
        max_length=100, help_text="prefix, partie devant '@'"
    )
    description = models.CharField(max_length=200, blank=True)
    public = models.BooleanField(
        default=False, help_text="visible sur l'interface public"
    )
    type_l = models.IntegerField("type", choices=TYPE_LISTE, default=0)

    def __str__(self):
        return self.description


# EOF
